summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/colourlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/colourlist.h')
-rw-r--r--kalarm/lib/colourlist.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalarm/lib/colourlist.h b/kalarm/lib/colourlist.h
index a20a44d6..8ec2b2a9 100644
--- a/kalarm/lib/colourlist.h
+++ b/kalarm/lib/colourlist.h
@@ -82,8 +82,8 @@ class ColourList
const_iterator fromLast() const { return mList.fromLast(); }
/** Returns an iterator pointing to the colour at position @p i in the list. */
const_iterator at(size_type i) const { return mList.at(i); }
- /** Returns true if the list contains the colour @p c. */
- size_type contains(const TQColor& c) const { return mList.contains(c.rgb()); }
+ /** Returns true if the list tqcontains the colour @p c. */
+ size_type tqcontains(const TQColor& c) const { return mList.tqcontains(c.rgb()); }
/** Returns an iterator pointing to the first occurrence of colour @p c in the list.
* Returns end() if colour @p c is not in the list.
*/